@@ -170,7 +170,15 @@ class NetworkPollerGrpcClient:
                             msg = await msg_q.get()
                         msg_q.task_done()
                         msg_size = msg.ByteSize()
-                        if size + msg_size > self.MAX_MESSAGE_SIZE:
+                        # PPA-1378 first we need to check if current message is not exceeding the maximum message size, if it is, break without setting it to a next_message
+                        if msg_size > self.MAX_MESSAGE_SIZE:
+                            next_message = None
+                            logging.warning(
+                                'AP: %s, NetworkElementUpdate message with size: %s, is exceeding maximum allowed size: %s',
+                                self.host, msg_size, self.MAX_MESSAGE_SIZE)
+                            break
+                        # break in case current message is less than maximum allowed but overall messages exceeding that. Setting current message be a next_message to form a new batch
+                        elif size + msg_size > self.MAX_MESSAGE_SIZE:
                             next_message = msg
                             break
                         else:
